@@ -1,9 +1,8 @@
 #' A function rather aimed at developers
-#' @import MassSpecWavelet
 #' @noRd
-
+#'
 peakSearch=function(datin){ ### datin is a vector
-  peakInfo = MassSpecWavelet::peakDetectionCWT(datin)
+  peakInfo = peakDetectionCWTR(datin)
   majorPeakInfo = peakInfo$majorPeakInfo
   peakIndex = majorPeakInfo$peakIndex
   return(peakIndex)
